<?php
/**
 * Moral Theme Customizer
 *
 * @package Moral
 */

/**
 * Get all the default values of the theme mods.
 */
function reblog_pro_get_default_mods() {
	$reblog_pro_default_mods = array(
		// Blog section
		'reblog_pro_blog_section_title' => esc_html__( 'Stay Updated. Happening Now.', 'reblog-pro' ),
		'reblog_pro_blog_section_sub_title' => esc_html__( 'Latest Blog', 'reblog-pro' ),

		// Footer copyright
		'reblog_pro_copyright_txt' => sprintf( esc_html__( 'Theme: %1$s by %2$s.', 'reblog-pro' ), 'Reblog Pro', '<a href="' . esc_url( 'http://moralthemes.com/' ) . '">Moral Themes</a>' ),

	);

	return apply_filters( 'reblog_pro_default_mods', $reblog_pro_default_mods );
}

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function reblog_pro_customize_register( $wp_customize ) {

	/**
	 * The radio image customize control extends the WP_Customize_Control class.  This class allows
	 * developers to create a list of image radio inputs.
	 *
	 * Note, the `$choices` array is slightly different than normal and should be in the form of
	 * `array(
		 *	$value => array( 'color' => $color_value ),
		 *	$value => array( 'color' => $color_value ),
	 * )`
	 *
	 */
	
	/**
	 * Multiple select customize control.
	 *
	 * @since  3.0.0
	 * @access public
	 */
	class Reblog_Pro_Customize_Control_Multiple_Select extends WP_Customize_Control {

		/**
		 * The type of customize control being rendered.
		 *
		 * @since  3.0.0
		 * @access public
		 * @var    string
		 */
		public $type = 'multiple-select';

		/**
		 * Add custom parameters to pass to the JS via JSON.
		 *
		 * @since  3.0.0
		 * @access public
		 * @return void
		 */
		public function to_json() {
			parent::to_json();

			// We need to make sure we have the correct color URL.
			foreach ( $this->choices as $value => $args )
				// $this->choices[ $value ]['color'] = esc_attr( $args['color'] );

			$this->json['choices'] = $this->choices;
			$this->json['link']    = $this->get_link();
			$this->json['value']   = $this->value();
			$this->json['id']      = $this->id;
		}

		/**
		 * Don't render the content via PHP.  This control is handled with a JS template.
		 *
		 * @since  4.0.0
		 * @access public
		 * @return bool
		 */
		protected function render_content() {}

		/**
		 * Underscore JS template to handle the control's output.
		 *
		 * @since  3.0.0
		 * @access public
		 * @return void
		 */
		public function content_template() { ?>

			<# if ( ! data.choices ) {
				return;
			} #>

			<# if ( data.label ) { #>
				<span class="customize-control-title">{{ data.label }}</span>
			<# } #>

			<# if ( data.description ) { #>
				<span class="description customize-control-description">{{{ data.description }}}</span>
			<# } #>

				<select multiple id="" name="_customize-{{ data.type }}-{{ data.id }}" {{{ data.link }}}>
				<# _.each( data.choices, function( args, choice ) { #>
					<option value="{{ choice }}">{{{args}}}</option>
				<# } ) #>
				</select>
		<?php }
	}
	$wp_customize->register_control_type( 'Reblog_Pro_Customize_Control_Multiple_Select'       );

	/**
	 * Radio color customize control.
	 *
	 * @since  3.0.0
	 * @access public
	 */
	class Reblog_Pro_Customize_Control_Radio_Color extends WP_Customize_Control {

		/**
		 * The type of customize control being rendered.
		 *
		 * @since  3.0.0
		 * @access public
		 * @var    string
		 */
		public $type = 'radio-color';

		/**
		 * Add custom parameters to pass to the JS via JSON.
		 *
		 * @since  3.0.0
		 * @access public
		 * @return void
		 */
		public function to_json() {
			parent::to_json();

			// We need to make sure we have the correct color URL.
			foreach ( $this->choices as $value => $args )
				$this->choices[ $value ]['color'] = esc_attr( $args['color'] );

			$this->json['choices'] = $this->choices;
			$this->json['link']    = $this->get_link();
			$this->json['value']   = $this->value();
			$this->json['id']      = $this->id;
		}

		/**
		 * Don't render the content via PHP.  This control is handled with a JS template.
		 *
		 * @since  4.0.0
		 * @access public
		 * @return bool
		 */
		protected function render_content() {}

		/**
		 * Underscore JS template to handle the control's output.
		 *
		 * @since  3.0.0
		 * @access public
		 * @return void
		 */
		public function content_template() { ?>

			<# if ( ! data.choices ) {
				return;
			} #>

			<# if ( data.label ) { #>
				<span class="customize-control-title">{{ data.label }}</span>
			<# } #>

			<# if ( data.description ) { #>
				<span class="description customize-control-description">{{{ data.description }}}</span>
			<# } #>

			<# _.each( data.choices, function( args, choice ) { #>
				<label>
					<input type="radio" value="{{ choice }}" name="_customize-{{ data.type }}-{{ data.id }}" {{{ data.link }}} <# if ( choice === data.value ) { #> checked="checked" <# } #> />

					<span class="screen-reader-text">{{ args.label }}</span>
					
					<# if ( 'custom' != choice ) { #>
						<span class="color-value" style="background-color: {{ args.color }}"></span>
					<# } else { #>
						<span class="color-value custom-color-value"></span>
					<# } #>
				</label>
			<# } ) #>
		<?php }
	}

	$wp_customize->register_control_type( 'Reblog_Pro_Customize_Control_Radio_Color' );


	$default = reblog_pro_get_default_mods();

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'reblog_pro_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'reblog_pro_customize_partial_blogdescription',
		) );
	}

	/**
	 *
	 * 
	 * Header panel
	 *
	 * 
	 */
	// Header panel
	$wp_customize->add_panel(
		'reblog_pro_header_panel',
		array(
			'title' => esc_html__( 'Header', 'reblog-pro' ),
			'priority' => 100
		)
	);

	$wp_customize->get_section( 'title_tagline' )->panel = 'reblog_pro_header_panel';

	// Header text display setting
	$wp_customize->add_setting(	
		'reblog_pro_header_text_display',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'reblog_pro_header_text_display',
		array(
			'section'		=> 'title_tagline',
			'type'			=> 'checkbox',
			'label'			=> esc_html__( 'Display Site Title and Tagline', 'reblog-pro' ),
		)
	);

	// Header section
	$wp_customize->add_section(
		'reblog_pro_header_section',
		array(
			'title' => esc_html__( 'Header', 'reblog-pro' ),
			'panel' => 'reblog_pro_header_panel',
		)
	);

	// Header menu sticky enable settings
	$wp_customize->add_setting(
		'reblog_pro_make_menu_sticky',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => false
		)
	);

	$wp_customize->add_control(
		'reblog_pro_make_menu_sticky',
		array(
			'section'		=> 'reblog_pro_header_section',
			'label'			=> esc_html__( 'Make menu sticky.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Header search form settings
	$wp_customize->add_setting(
		'reblog_pro_show_search',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true
		)
	);

	$wp_customize->add_control(
		'reblog_pro_show_search',
		array(
			'section'		=> 'reblog_pro_header_section',
			'label'			=> esc_html__( 'Show search.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);


	/**
	 *
	 * General settings panel
	 * 
	 */
	// General settings panel
	$wp_customize->add_panel(
		'reblog_pro_general_panel',
		array(
			'title' => esc_html__( 'Advanced Settings', 'reblog-pro' ),
			'priority' => 107
		)
	);

	$wp_customize->get_section( 'colors' )->panel = 'reblog_pro_general_panel';
	
	// Header title color setting
	$wp_customize->add_setting(	
		'reblog_pro_header_title_color',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_hex_color',
			'default' => '#fff',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'reblog_pro_header_title_color',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Site title Color:', 'reblog-pro' ),
			)
		)
	);

	// Header tagline color setting
	$wp_customize->add_setting(	
		'reblog_pro_header_tagline',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_hex_color',
			'default' => '#fff',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'reblog_pro_header_tagline',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Site tagline Color:', 'reblog-pro' ),
			)
		)
	);
	
	// Color scheme setting
	$wp_customize->add_setting(	
		'reblog_pro_color_scheme',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_select',
			'default'	=> 'default',
		)
	);

	$wp_customize->add_control( 
		new Reblog_Pro_Customize_Control_Radio_Color( 
		$wp_customize,
		'reblog_pro_color_scheme',
		array(
			'section'		=> 'colors',
			'type'			=> 'radio-color',
			'label'			=> esc_html__( 'Color scheme:', 'reblog-pro' ),
			'choices'		=> array( 
				'default' => array( 
					'color' => '#117eff'
				),
				'yellow' => array( 
					'color' => '#feb900'
				),
				'green' => array( 
					'color' => '#74c000'
				),
				'red' => array( 
					'color' => '#e7174d'
				),
				'custom' => array( 
					'color' => '#E1222A'
				),
			),
		)
	)
	);

	// Custom color scheme scheme setting
	$wp_customize->add_setting(	
		'reblog_pro_custom_color_scheme',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_hex_color',
			'default' => '#117eff',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'reblog_pro_custom_color_scheme',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Custom color:', 'reblog-pro' ),
				'active_callback' => 'reblog_pro_if_custom_color_scheme',
			)
		)
	);

	$wp_customize->get_section( 'background_image' )->panel   = 'reblog_pro_general_panel';
	$wp_customize->get_section( 'custom_css' )->panel         = 'reblog_pro_general_panel';

	/**
	 * General settings
	 */
	// General settings
	$wp_customize->add_section(
		'reblog_pro_general_section',
		array(
			'title' => esc_html__( 'General', 'reblog-pro' ),
			'panel' => 'reblog_pro_general_panel',
		)
	);

	// Enable smoothscroll setting
	$wp_customize->add_setting(
		'reblog_pro_smoothscroll_enable',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_smoothscroll_enable',
		array(
			'section'		=> 'reblog_pro_general_section',
			'label'			=> esc_html__( 'Enable smooth scroll.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Backtop enable setting
	$wp_customize->add_setting(
		'reblog_pro_back_to_top_enable',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_back_to_top_enable',
		array(
			'section'		=> 'reblog_pro_general_section',
			'label'			=> esc_html__( 'Enable Scroll up.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Global Layout
	 */
	// Global Layout
	$wp_customize->add_section(
		'reblog_pro_global_layout',
		array(
			'title' => esc_html__( 'Global Layout', 'reblog-pro' ),
			'panel' => 'reblog_pro_general_panel',
		)
	);

	// Global site layout setting
	$wp_customize->add_setting(
		'reblog_pro_site_layout',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_select',
			'default' => 'wide',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'reblog_pro_site_layout',
		array(
			'section'		=> 'reblog_pro_global_layout',
			'label'			=> esc_html__( 'Site layout', 'reblog-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'boxed' => esc_html__( 'Boxed', 'reblog-pro' ), 
				'wide' => esc_html__( 'Wide', 'reblog-pro' ), 
				'frame' => esc_html__( 'Frame', 'reblog-pro' ), 
			),
		)
	);


	// Global archive layout setting
	$wp_customize->add_setting(
		'reblog_pro_archive_layout',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_select',
			'default' => 'classic-design',
		)
	);

	$wp_customize->add_control(
		'reblog_pro_archive_layout',
		array(
			'section'		=> 'reblog_pro_global_layout',
			'label'			=> esc_html__( 'Archive Layout', 'reblog-pro' ),
			'description'			=> esc_html__( 'This option works on all archive pages like: search, date, category, "Your latest posts" and so on.', 'reblog-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'classic-design' => esc_html__( 'Classic Design', 'reblog-pro' ), 
				'modern-design' => esc_html__( 'Modern Design', 'reblog-pro' ), 
				'sleek-design' => esc_html__( 'Sleek Design', 'reblog-pro' ), 
			),
		)
	);

	// Global page layout setting
	$wp_customize->add_setting(
		'reblog_pro_global_page_layout',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_select',
			'default' => 'right',
		)
	);

	$wp_customize->add_control(
		'reblog_pro_global_page_layout',
		array(
			'section'		=> 'reblog_pro_global_layout',
			'label'			=> esc_html__( 'Global page sidebar', 'reblog-pro' ),
			'description'			=> esc_html__( 'This option works only on single pages including "Posts page". This setting can be overridden for single page from the metabox too.', 'reblog-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'left' => esc_html__( 'Left', 'reblog-pro' ), 
				'right' => esc_html__( 'Right', 'reblog-pro' ), 
				'no' => esc_html__( 'No Sidebar', 'reblog-pro' ), 
			),
		)
	);

	// Global post layout setting
	$wp_customize->add_setting(
		'reblog_pro_global_post_layout',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_select',
			'default' => 'right',
		)
	);

	$wp_customize->add_control(
		'reblog_pro_global_post_layout',
		array(
			'section'		=> 'reblog_pro_global_layout',
			'label'			=> esc_html__( 'Global post sidebar', 'reblog-pro' ),
			'description'			=> esc_html__( 'This option works only on single posts. This setting can be overridden for single post from the metabox too.', 'reblog-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'left' => esc_html__( 'Left', 'reblog-pro' ), 
				'right' => esc_html__( 'Right', 'reblog-pro' ), 
				'no' => esc_html__( 'No Sidebar', 'reblog-pro' ), 
			),
		)
	);

	/**
	 * Blog/Archive section 
	 */
	// Blog/Archive section 
	$wp_customize->add_section(
		'reblog_pro_archive_settings',
		array(
			'title' => esc_html__( 'Archive/Blog', 'reblog-pro' ),
			'description' => esc_html__( 'Settings for archive pages including blog page too.', 'reblog-pro' ),
			'panel' => 'reblog_pro_general_panel',
		)
	);

	// archive posts filter setting
	$wp_customize->add_setting(
		'reblog_pro_archive_tag_filter',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_select',
		)
	);

	$wp_customize->add_control( new Reblog_Pro_Customize_Control_Multiple_Select ( $wp_customize,
		'reblog_pro_archive_tag_filter',
		array(
			'section'		=> 'reblog_pro_archive_settings',
			'label'			=> esc_html__( 'Add Tags Filter:', 'reblog-pro' ),
			'description' => esc_html__( 'Press CTRL and select multiple tags to filter posts in blog/archive pages.', 'reblog-pro' ),
			'type'			=> 'multiple-select',
			'choices'		=> reblog_pro_get_post_tags_choices(),
		)
	) );

	// Archive excerpt length setting
	$wp_customize->add_setting(
		'reblog_pro_archive_excerpt_length',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_number_range',
			'default' => 60,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_archive_excerpt_length',
		array(
			'section'		=> 'reblog_pro_archive_settings',
			'label'			=> esc_html__( 'Excerpt more length:', 'reblog-pro' ),
			'type'			=> 'number',
			'input_attrs'   => array( 'min' => 5 ),
		)
	);

	// Date enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_archive_date',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_archive_date',
		array(
			'section'		=> 'reblog_pro_archive_settings',
			'label'			=> esc_html__( 'Enable date.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Category enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_archive_cat',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_archive_cat',
		array(
			'section'		=> 'reblog_pro_archive_settings',
			'label'			=> esc_html__( 'Enable category.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Pagination type setting
	$wp_customize->add_setting(
		'reblog_pro_archive_pagination_type',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_select',
			'default' => 'numeric',
		)
	);

	$archive_pagination_description = '';
	$archive_pagination_choices = array( 
				'disable' => esc_html__( '--Disable--', 'reblog-pro' ),
				'numeric' => esc_html__( 'Numeric', 'reblog-pro' ),
				'older_newer' => esc_html__( 'Older / Newer', 'reblog-pro' ),
			);
	if ( ! class_exists( 'JetPack' ) ) {
		$archive_pagination_description = sprintf( esc_html__( 'We recommend to install %1$sJetpack%2$s and enable %3$sInfinite Scroll%4$s feature for automatic loading of posts.', 'reblog-pro' ), '<a target="_blank" href="http://wordpress.org/plugins/jetpack">', '</a>', '<b>', '</b>' );
	} else {
		$archive_pagination_choices['infinite_scroll'] = esc_html__( 'Infinite Load', 'reblog-pro' );
	}
	$wp_customize->add_control(
		'reblog_pro_archive_pagination_type',
		array(
			'section'		=> 'reblog_pro_archive_settings',
			'label'			=> esc_html__( 'Pagination type:', 'reblog-pro' ),
			'description'			=>  $archive_pagination_description,
			'type'			=> 'select',
			'choices'		=> $archive_pagination_choices,
		)
	);


	/**
	 * Single setting section 
	 */
	// Single setting section 
	$wp_customize->add_section(
		'reblog_pro_single_settings',
		array(
			'title' => esc_html__( 'Single Posts', 'reblog-pro' ),
			'description' => esc_html__( 'Settings for all single posts.', 'reblog-pro' ),
			'panel' => 'reblog_pro_general_panel',
		)
	);

	// Date enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_single_date',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_single_date',
		array(
			'section'		=> 'reblog_pro_single_settings',
			'label'			=> esc_html__( 'Enable date.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Category enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_single_cat',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_single_cat',
		array(
			'section'		=> 'reblog_pro_single_settings',
			'label'			=> esc_html__( 'Enable category.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Tag enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_single_tag',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_single_tag',
		array(
			'section'		=> 'reblog_pro_single_settings',
			'label'			=> esc_html__( 'Enable tags.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Comment enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_single_comment',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_single_comment',
		array(
			'section'		=> 'reblog_pro_single_settings',
			'label'			=> esc_html__( 'Enable comment.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);


	// Author enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_single_author',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_single_author',
		array(
			'section'		=> 'reblog_pro_single_settings',
			'label'			=> esc_html__( 'Enable author.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Featured image enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_single_featured_img',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_single_featured_img',
		array(
			'section'		=> 'reblog_pro_single_settings',
			'label'			=> esc_html__( 'Enable featured image.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Pagination enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_single_pagination',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_single_pagination',
		array(
			'section'		=> 'reblog_pro_single_settings',
			'label'			=> esc_html__( 'Enable pagination.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Single pages setting section 
	 */
	// Single pages setting section 
	$wp_customize->add_section(
		'reblog_pro_single_page_settings',
		array(
			'title' => esc_html__( 'Single Pages', 'reblog-pro' ),
			'description' => esc_html__( 'Settings for all single pages.', 'reblog-pro' ),
			'panel' => 'reblog_pro_general_panel',
		)
	);

	// Featured image enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_single_page_featured_img',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_single_page_featured_img',
		array(
			'section'		=> 'reblog_pro_single_page_settings',
			'label'			=> esc_html__( 'Enable featured image.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Pagination enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_single_page_pagination',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_single_page_pagination',
		array(
			'section'		=> 'reblog_pro_single_page_settings',
			'label'			=> esc_html__( 'Enable pagination.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Reset all settings
	 */
	// Reset settings section
	$wp_customize->add_section(
		'reblog_pro_reset_sections',
		array(
			'title' => esc_html__( 'Reset all', 'reblog-pro' ),
			'description' => esc_html__( 'Reset all settings to default.', 'reblog-pro' ),
			'panel' => 'reblog_pro_general_panel',
		)
	);

	// Reset sortable order setting
	$wp_customize->add_setting(
		'reblog_pro_reset_settings',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => false,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'reblog_pro_reset_settings',
		array(
			'section'		=> 'reblog_pro_reset_sections',
			'label'			=> esc_html__( 'Reset all settings?', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 *
	 *
	 * Footer copyright
	 *
	 *
	 */
	// Footer copyright
	$wp_customize->add_section(
		'reblog_pro_footer_section',
		array(
			'title' => esc_html__( 'Footer', 'reblog-pro' ),
			'priority' => 106,
			// 'panel' => 'reblog_pro_general_panel',
		)
	);

	// Footer social menu enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_footer_social_menu',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_footer_social_menu',
		array(
			'section'		=> 'reblog_pro_footer_section',
			'label'			=> esc_html__( 'Enable social menu.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Footer text enable setting
	$wp_customize->add_setting(
		'reblog_pro_enable_footer_text',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'reblog_pro_enable_footer_text',
		array(
			'section'		=> 'reblog_pro_footer_section',
			'label'			=> esc_html__( 'Enable footer text.', 'reblog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Footer copyright setting
	$wp_customize->add_setting(
		'reblog_pro_copyright_txt',
		array(
			'sanitize_callback' => 'reblog_pro_sanitize_html',
			'default' => $default['reblog_pro_copyright_txt'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'reblog_pro_copyright_txt',
		array(
			'section'		=> 'reblog_pro_footer_section',
			'label'			=> esc_html__( 'Copyright text:', 'reblog-pro' ),
			'type'			=> 'textarea',
			'active_callback' => 'reblog_pro_if_footer_text_enable',
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'reblog_pro_copyright_txt', 
		array(
	        'selector'            => '#colophon .site-info .footer-copyright',
			'render_callback'     => 'reblog_pro_copyright_partial',
    	) 
    );
}
add_action( 'customize_register', 'reblog_pro_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function reblog_pro_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function reblog_pro_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function reblog_pro_customize_preview_js() {
	wp_enqueue_script( 'reblog-pro-customizer', get_theme_file_uri( '/assets/js/customizer.js' ), array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'reblog_pro_customize_preview_js' );

/**
 * Binds JS handlers for Customizer controls.
 */
function reblog_pro_customize_control_js() {


	wp_enqueue_style( 'reblog-pro-customize-style', get_theme_file_uri( '/assets/css/customize-controls.css' ), array(), '20151215' );

	wp_enqueue_script( 'reblog-pro-customize-control', get_theme_file_uri( '/assets/js/customize-control.js' ), array( 'jquery', 'customize-controls' ), '20151215', true );
	$localized_data = array( 
		'refresh_msg' => esc_html__( 'Refresh the page after Save and Publish.', 'reblog-pro' ),
		'reset_msg' => esc_html__( 'Warning!!! This will reset all the settings. Refresh the page after Save and Publish to reset all.', 'reblog-pro' ),
	);

	wp_localize_script( 'reblog-pro-customize-control', 'localized_data', $localized_data );
}
add_action( 'customize_controls_enqueue_scripts', 'reblog_pro_customize_control_js' );

/**
 *
 * Sanitization callbacks.
 * 
 */

/**
 * Checkbox sanitization callback example.
 * 
 * Sanitization callback for 'checkbox' type controls. This callback sanitizes `$checked`
 * as a boolean value, either TRUE or FALSE.
 *
 * @param bool $checked Whether the checkbox is checked.
 * @return bool Whether the checkbox is checked.
 */
function reblog_pro_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}


/**
 * HEX Color sanitization callback example.
 *
 * - Sanitization: hex_color
 * - Control: text, WP_Customize_Color_Control
 *
 */
function reblog_pro_sanitize_hex_color( $hex_color, $setting ) {
	// Sanitize $input as a hex value without the hash prefix.
	$hex_color = sanitize_hex_color( $hex_color );
	
	// If $input is a valid hex value, return it; otherwise, return the default.
	return ( ! is_null( $hex_color ) ? $hex_color : $setting->default );
}


/**
 * Select sanitization callback example.
 *
 * - Sanitization: select, multiple-select
 * - Control: select, radio
 */
function reblog_pro_sanitize_select( $input, $setting ) {
	$choices = $setting->manager->get_control( $setting->id )->choices;
	
	if ( is_array( $input ) ) {
		foreach ( $input as $value ) {
		// Ensure input is a slug.
			$value = sanitize_key( $value );
			
			if ( ! array_key_exists( $value, $choices ) ) {
            	return $setting->default;
        	}
		}
	} else {
		// Ensure input is a slug.
		$input = sanitize_key( $input );
		
		if ( ! array_key_exists( $input, $choices ) ) {
        	return $setting->default;
    	}
	}

	return $input;
}

/**
 * Drop-down Pages sanitization callback example.
 *
 * - Sanitization: dropdown-pages
 * - Control: dropdown-pages
 * 
 */
function reblog_pro_sanitize_dropdown_pages( $page_id, $setting ) {
	// Ensure $input is an absolute integer.
	$page_id = absint( $page_id );
	
	// If $page_id is an ID of a published page, return it; otherwise, return the default.
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

/**
 * Number Range sanitization callback example.
 *
 * - Sanitization: number_range
 * - Control: number, tel
 * 
 */
function reblog_pro_sanitize_number_range( $number, $setting ) {
	
	// Ensure input is an absolute integer.
	$number = absint( $number );
	
	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;
	
	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );
	
	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );
	
	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );
	
	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}

/**
 * HTML sanitization callback example.
 *
 * - Sanitization: html
 * - Control: text, textarea
 *
 * @param string $html HTML to sanitize.
 * @return string Sanitized HTML.
 */
function reblog_pro_sanitize_html( $html ) {
	return wp_filter_post_kses( $html );
}

/**
 *
 * Active callbacks.
 * 
 */

/**
 * Check if the footer text is enabled
 */
function reblog_pro_if_footer_text_enable( $control ) {
	return $control->manager->get_setting( 'reblog_pro_enable_footer_text' )->value();
}

/**
 * Check if custom color scheme is enabled
 */
function reblog_pro_if_custom_color_scheme( $control ) {
	return 'custom' === $control->manager->get_setting( 'reblog_pro_color_scheme' )->value();
}

/**
 * Selective refresh for footer copyright.
 */
function reblog_pro_copyright_partial() {
	return wp_kses_post( get_theme_mod( 'reblog_pro_copyright_txt' ) );
}

